@@ -956,11 +956,14 @@ gboolean configlet_open(void)
 		cg->encodings.encodings = encodings_load();
 
 		connect_generic_handlers(cg);
+		CONFIGLET_CONNECT(cg->glade, cg->options, on_radio_toggled);
 
 		configlet_setup_family(cg, &cg->profile, "Profiles");
 		configlet_setup_family(cg, &cg->colours, "Colours");
 		configlet_setup_family(cg, &cg->shortcuts, "Shortcuts");
 		configlet_setup_family(cg, &cg->encodings, "encodings");
+		
+		capplet_set_radio(cg->glade, cg->options, "warn_close", 2);
 
 		capplet_inc_windows();
 		gtk_widget_show(cg->widget);
