@@ -36,6 +36,7 @@ char *global_options_bindir = NULL;
 char *global_options_directory = NULL;
 gboolean global_options_replace = FALSE;
 gboolean global_options_fullscreen = FALSE;
+gboolean global_options_tab = FALSE;
 
 static void correct_scheme(const char *bad_name, const char *good_name)
 {
@@ -61,6 +62,7 @@ static void global_options_reset(void)
 	global_options_directory = NULL;
 	global_options_replace = FALSE;
 	global_options_fullscreen = FALSE;
+	global_options_tab = FALSE;
 	options_reload_keyfile(global_options);
 	correct_schemes();
 }
@@ -74,8 +76,9 @@ static gboolean global_options_show_usage(const gchar *option_name,
 	  "    [--profile=PROFILE|-p PROFILE] \n"
 	  "    [--colour-scheme=SCHEME|--color-scheme=SCHEME|-c SCHEME]\n"
 	  "    [--shortcut-scheme=SCHEME|-s SCHEME]\n"
-	  "    [--fullscreen|-f] [--zoom=ZOOM|-z ZOOM] [--title=TITLE|-t TITLE]\n"
-	  "    [--separate] [--replace] [--directory=DIRECTORY|-d DIRECTORY]\n"
+	  "    [--fullscreen|-f] [--zoom=ZOOM|-z ZOOM] [--title=TITLE|-T TITLE]\n"
+	  "    [--separate] [--replace] [--tab]\n"
+	  "    [--directory=DIRECTORY|-d DIRECTORY]\n"
 	  "    [--show-menubar] [--hide-menubar] [-e|--execute COMMAND]\n");
 	exit(0);
 	return TRUE;
@@ -211,15 +214,20 @@ static GOptionEntry global_g_options[] = {
 		N_("Replace any existing process as ROXTerm's\n"
 		"                                   D-BUS service provider"),
 		NULL },
+	{ "title", 'T', G_OPTION_FLAG_IN_MAIN,
+		G_OPTION_ARG_CALLBACK, global_options_set_string,
+		N_("Set window title"), N_("TITLE") },
+	{ "tab", 0, G_OPTION_FLAG_IN_MAIN,
+		G_OPTION_ARG_NONE, &global_options_tab,
+		N_("Open a tab in an existing window instead of\n"
+		"                                   a new window if possible"),
+		NULL },
 	{ "execute", 'e', G_OPTION_FLAG_IN_MAIN | G_OPTION_FLAG_NO_ARG,
 		G_OPTION_ARG_CALLBACK, global_options_swallow_execute,
 		N_("Execute remainder of command line inside the\n"
 		"                                   terminal. "
 		"Must be the final option."),
 		NULL },
-	{ "title", 't', G_OPTION_FLAG_IN_MAIN,
-		G_OPTION_ARG_CALLBACK, global_options_set_string,
-		N_("Set window title"), N_("TITLE") },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
