@@ -105,13 +105,15 @@ struct MenuTree {
 	GSList *encodings_group;
 	int n_encodings;
 	gboolean disable_shortcuts;
+	gboolean disable_tab_shortcuts;
 };
 
 /* Builds a menu tree. The GType should either be GTK_TYPE_MENU_BAR or
  * GTK_TYPE_MENU.
  */
 MenuTree *menutree_new(Options *shortcuts, GtkAccelGroup * accel_group,
-	GType menu_type, gboolean disable_shortcuts, gpointer user_data);
+	GType menu_type, gboolean disable_shortcuts,
+	gboolean disable_tab_shortcuts, gpointer user_data);
 
 /* A "raw" handler for "toggled" signals on encodings items. The user_data
  * argument will be as passed to menutree_new. The client should work out
@@ -244,6 +246,8 @@ inline static void menutree_select_tab(MenuTree * tree, GtkWidget * menu_item)
 
 void menutree_disable_shortcuts(MenuTree *tree, gboolean disable);
 
+void menutree_disable_tab_shortcuts(MenuTree *tree, gboolean disable);
+
 #endif /* MENUTREE_H */
 
 /* vi:set sw=4 ts=4 noet cindent cino= */
