@@ -114,7 +114,7 @@ static MultiTabToNewWindowHandler multi_tab_to_new_window_handler;
 static MultiWinZoomHandler multi_win_zoom_handler;
 static MultiWinGetDisableMenuShortcuts multi_win_get_disable_menu_shortcuts;
 static MultiWinInitialTabs multi_win_initial_tabs;
-
+static MultiWinDeleteHandler multi_win_delete_handler;
 
 static gboolean multi_win_notify_tab_removed(MultiWin *, MultiTab *);
 
@@ -152,7 +152,8 @@ void multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
 	MultiTabToNewWindowHandler tab_to_new_window_handler,
 	MultiWinZoomHandler zoom_handler,
 	MultiWinGetDisableMenuShortcuts get_disable_menu_shortcuts,
-	MultiWinInitialTabs initial_tabs)
+	MultiWinInitialTabs initial_tabs,
+	MultiWinDeleteHandler delete_handler)
 {
 	multi_tab_filler = filler;
 	multi_tab_destructor = destructor;
@@ -163,6 +164,7 @@ void multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
 	multi_win_zoom_handler = zoom_handler;
 	multi_win_get_disable_menu_shortcuts = get_disable_menu_shortcuts;
 	multi_win_initial_tabs = initial_tabs;
+	multi_win_delete_handler = delete_handler;
 }
 
 MultiTab *multi_tab_new(MultiWin * parent, gpointer user_data_template)
@@ -765,6 +767,14 @@ static void tab_set_name_from_clipboard_callback(GtkClipboard *clp,
 	multi_tab_set_name(tab, text);
 }
 
+static gboolean multi_win_focus_in(GtkWidget *widget, GdkEventFocus *event,
+		MultiWin *win)
+{
+	multi_win_all = g_list_remove(multi_win_all, win);
+	multi_win_all = g_list_prepend(multi_win_all, win);
+	return FALSE;
+}
+
 #if DO_OWN_TAB_DRAGGING
 static gboolean tab_clicked_handler(GtkWidget *widget,
 		GdkEventButton *event, MultiTab *tab)
@@ -1169,6 +1179,11 @@ MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
 	win->gtkwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	win->destroy_handler = g_signal_connect(GTK_OBJECT(win->gtkwin),
 		"destroy", G_CALLBACK(multi_win_destroy_handler), win);
+	if (multi_win_delete_handler)
+	{
+		g_signal_connect(GTK_OBJECT(win->gtkwin), "delete-event",
+				G_CALLBACK(multi_win_delete_handler), win);
+	}
 
 	win->vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(win->gtkwin), win->vbox);
@@ -1205,6 +1220,8 @@ MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
 	gtk_box_pack_start_defaults(GTK_BOX(win->vbox), win->notebook);
 	g_signal_connect(win->notebook, "switch-page",
 		G_CALLBACK(multi_win_page_switched), win);
+	g_signal_connect(win->gtkwin, "focus-in-event",
+		G_CALLBACK(multi_win_focus_in), win);
 #if !DO_OWN_TAB_DRAGGING
 	gtk_notebook_set_group_id(GTK_NOTEBOOK(win->notebook),
 			MULTI_WIN_NOTEBOOK_GROUP);
@@ -1548,6 +1565,11 @@ MultiTab *multi_win_get_current_tab(MultiWin * win)
 	return win->current_tab;
 }
 
+guint multi_win_get_ntabs(MultiWin * win)
+{
+	return win->ntabs;
+}
+
 gpointer multi_win_get_user_data_for_current_tab(MultiWin * win)
 {
 	if (!win->current_tab)
@@ -1693,6 +1715,7 @@ gboolean multi_win_validate_title_template(const char *tt)
 	return TRUE;
 }
 
+/* This is maintained in order of most recently focused */
 GList *multi_win_all = NULL;
 
 /* vi:set sw=4 ts=4 noet cindent cino= */
