@@ -89,6 +89,9 @@ typedef void (*MultiWinGetDisableMenuShortcuts)(gpointer user_data,
 typedef void (*MultiWinInitialTabs)(gpointer user_data,
 		GtkPositionType *p_pos, int *p_num);
 
+/* A handler for delete-event */
+typedef void (*MultiWinDeleteHandler)(GtkWidget *, GdkEvent *, MultiWin *win);
+
 /* Call to set up function hooks. See MultiTabFiller etc above.
  * menu_signal_connector is called each time a new window is created to give
  * the client a chance to connect its signal handlers; each handler will
@@ -97,7 +100,8 @@ void
 multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
 	MultiWinMenuSignalConnector menu_signal_connector,
 	MultiWinGeometryFunc, MultiWinSizeFunc, MultiTabToNewWindowHandler,
-	MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs);
+	MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs,
+	MultiWinDeleteHandler);
 
 /* Register a MultiTabSelectionHandler (see above) */
 void
@@ -238,6 +242,8 @@ multi_win_menu_connect_swapped(MultiWin * win, MenuTreeID id,
 
 MultiTab *multi_win_get_current_tab(MultiWin * win);
 
+guint multi_win_get_ntabs(MultiWin * win);
+
 gpointer multi_win_get_user_data_for_current_tab(MultiWin * win);
 
 MenuTree *multi_win_get_menu_bar(MultiWin * win);
